@@ -3,7 +3,7 @@ package App::ModuleBuildTiny;
 use 5.014;
 use strict;
 use warnings;
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 
 use Exporter 5.57 'import';
 our @EXPORT = qw/modulebuildtiny/;
@@ -262,7 +262,7 @@ my %actions = (
 		my $dist = App::ModuleBuildTiny::Dist->new;
 		my @args;
 		push @args, '-j', $jobs if defined $jobs;
-		return $dist->run(command => [ 'prove', '-br', @dirs ], build => 1, verbose => 1);
+		return $dist->run(command => [ 'prove', '-br', @args, @dirs ], build => 1, verbose => 1);
 	},
 	upload => sub {
 		my @arguments = @_;
@@ -347,13 +347,14 @@ my %actions = (
 	regenerate => sub {
 		my @arguments = @_;
 		my $config = get_config;
+		my $specific = @arguments;
+		my @files = $specific ? @arguments : @regenerate_files;
 		my %opts = (
-			bump   => $config->{auto_bump},
-			commit => $config->{auto_git},
+			bump   => $config->{auto_bump} && !$specific,
+			commit => $config->{auto_git} && !$specific,
 			scan   => $config->{auto_scan},
 		);
 		GetOptionsFromArray(\@arguments, \%opts, qw/trial bump! version=s verbose dry_run|dry-run commit! scan! message=s/) or return 2;
-		my @files = @arguments ? @arguments : @regenerate_files;
 
 		regenerate(\@files, $config, %opts);
 
